8152054: fix @ignored langtools/test/jdk/javadoc/tool/ tests
authorksrini
Wed, 10 Aug 2016 16:19:09 -0700
changeset 40310 a979695d72a1
parent 40309 4c9d829b21ea
child 40311 bb76098875c8
8152054: fix @ignored langtools/test/jdk/javadoc/tool/ tests Reviewed-by: jjg
langtools/test/ProblemList.txt
langtools/test/jdk/javadoc/tool/8025693/Test.java
langtools/test/jdk/javadoc/tool/T4696488.java
langtools/test/jdk/javadoc/tool/badSuper/BadSuper.java
langtools/test/jdk/javadoc/tool/enum/docComments/Main.java
langtools/test/jdk/javadoc/tool/enum/enumType/Main.java
langtools/test/jdk/javadoc/tool/generics/genericClass/Main.java
langtools/test/jdk/javadoc/tool/generics/genericClass/expected.out
langtools/test/jdk/javadoc/tool/generics/genericClass/pkg1/A.java
langtools/test/jdk/javadoc/tool/generics/genericInnerAndOuter/Main.java
langtools/test/jdk/javadoc/tool/generics/genericInnerAndOuter/expected.out
langtools/test/jdk/javadoc/tool/generics/genericInnerAndOuter/pkg1/O.java
langtools/test/jdk/javadoc/tool/generics/genericInnerAndOuter/pkg1/X.java
langtools/test/jdk/javadoc/tool/generics/genericInterface/Main.java
langtools/test/jdk/javadoc/tool/generics/genericInterface/expected.out
langtools/test/jdk/javadoc/tool/generics/genericInterface/pkg1/A.java
langtools/test/jdk/javadoc/tool/generics/genericMethod/Main.java
langtools/test/jdk/javadoc/tool/generics/genericMethod/expected.out
langtools/test/jdk/javadoc/tool/generics/genericMethod/pkg1/A.java
langtools/test/jdk/javadoc/tool/generics/genericSuper/Main.java
langtools/test/jdk/javadoc/tool/generics/genericSuper/expected.out
langtools/test/jdk/javadoc/tool/generics/genericSuper/pkg1/A.java
langtools/test/jdk/javadoc/tool/generics/supertypes/Main.java
langtools/test/jdk/javadoc/tool/generics/supertypes/expected.out
langtools/test/jdk/javadoc/tool/generics/supertypes/pkg1/A.java
langtools/test/jdk/javadoc/tool/generics/supertypes/pkg1/B.java
langtools/test/jdk/javadoc/tool/generics/throwsGeneric/Main.java
langtools/test/jdk/javadoc/tool/generics/throwsGeneric/expected.out
langtools/test/jdk/javadoc/tool/generics/throwsGeneric/pkg1/A.java
langtools/test/jdk/javadoc/tool/generics/tparamCycle/Main.java
langtools/test/jdk/javadoc/tool/generics/tparamCycle/pkg1/LikeEnum.java
langtools/test/jdk/javadoc/tool/generics/tparamTagOnMethod/Main.java
langtools/test/jdk/javadoc/tool/generics/tparamTagOnMethod/expected.out
langtools/test/jdk/javadoc/tool/generics/tparamTagOnMethod/pkg1/A.java
langtools/test/jdk/javadoc/tool/generics/tparamTagOnType/Main.java
langtools/test/jdk/javadoc/tool/generics/tparamTagOnType/expected.out
langtools/test/jdk/javadoc/tool/generics/tparamTagOnType/pkg1/A.java
langtools/test/jdk/javadoc/tool/generics/wildcards/Main.java
langtools/test/jdk/javadoc/tool/generics/wildcards/expected.out
langtools/test/jdk/javadoc/tool/generics/wildcards/pkg1/A.java
langtools/test/jdk/javadoc/tool/imports/I.java
langtools/test/jdk/javadoc/tool/imports/MissingImport.java
langtools/test/jdk/javadoc/tool/lib/Tester.java
langtools/test/jdk/javadoc/tool/sourceOnly/Test.java
langtools/test/jdk/javadoc/tool/sourceOnly/p/NonSource.jasm
langtools/test/jdk/javadoc/tool/sourceOnly/p/SourceOnly.java
langtools/test/jdk/javadoc/tool/sourceOption/SourceOption.java
langtools/test/jdk/javadoc/tool/subpackageIgnore/SubpackageIgnore.java
langtools/test/jdk/javadoc/tool/varArgs/Main.java
--- a/langtools/test/ProblemList.txt	Wed Aug 10 15:54:25 2016 -0700
+++ b/langtools/test/ProblemList.txt	Wed Aug 10 16:19:09 2016 -0700
@@ -26,29 +26,10 @@
 ###########################################################################
 #
 # javadoc
-
-jdk/javadoc/tool/6176978/T6176978.java                                          8152049    generic-all    no longer applicable, should delete
-jdk/javadoc/tool/InlineTagsWithBraces.java                                      8152050    generic-all    API, re-evaluate @bold, @maybe causes doclint to throw up.
-jdk/javadoc/tool/LangVers.java                                                  8152051    generic-all    API, re-evaluate, unsure of this test.
 jdk/javadoc/tool/VerifyLocale.java                                              8149565    generic-all    -locale option issues
-jdk/javadoc/tool/enum/docComments/Main.java                                     8152054    generic-all    API modifications
-jdk/javadoc/tool/enum/enumType/Main.java                                        8152054    generic-all    API modifications
-jdk/javadoc/tool/generics/genericClass/Main.java                                8152054    generic-all    API modifications
-jdk/javadoc/tool/generics/genericInnerAndOuter/Main.java                        8152054    generic-all    API modifications
-jdk/javadoc/tool/generics/genericInterface/Main.java                            8152054    generic-all    API modifications
-jdk/javadoc/tool/generics/genericMethod/Main.java                               8152054    generic-all    API modifications
-jdk/javadoc/tool/generics/genericSuper/Main.java                                8152054    generic-all    API modifications
-jdk/javadoc/tool/generics/supertypes/Main.java                                  8152054    generic-all    API modifications
-jdk/javadoc/tool/generics/throwsGeneric/Main.java                               8152054    generic-all    API modifications
-jdk/javadoc/tool/generics/tparamCycle/Main.java                                 8152054    generic-all    API modifications
-jdk/javadoc/tool/generics/tparamTagOnMethod/Main.java                           8152054    generic-all    API modifications
-jdk/javadoc/tool/generics/tparamTagOnType/Main.java                             8152054    generic-all    API modifications
-jdk/javadoc/tool/generics/wildcards/Main.java                                   8152054    generic-all    API modifications
-jdk/javadoc/tool/imports/MissingImport.java                                     8152054    generic-all    API modifications, testing deprecated APIs.
-jdk/javadoc/tool/sourceOnly/Test.java                                           8152054    generic-all    API modifications
-jdk/javadoc/tool/sourceOption/SourceOption.java                                 8152054    generic-all    API modifications
-jdk/javadoc/tool/subpackageIgnore/SubpackageIgnore.java                         8152054    generic-all    API modifications
-jdk/javadoc/tool/varArgs/Main.java                                              8152054    generic-all    API modifications
+jdk/javadoc/tool/enum/docComments/Main.java                                     8152313    generic-all    convert to doclet test framework
+jdk/javadoc/tool/enum/enumType/Main.java                                        8152313    generic-all    convert to doclet test framework
+jdk/javadoc/tool/varArgs/Main.java                                              8152313    generic-all    convert to doclet test framework
 
 ###########################################################################
 #
--- a/langtools/test/jdk/javadoc/tool/8025693/Test.java	Wed Aug 10 15:54:25 2016 -0700
+++ b/langtools/test/jdk/javadoc/tool/8025693/Test.java	Wed Aug 10 16:19:09 2016 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2013, 2016, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,7 +25,7 @@
  * @test
  * @bug 8025693
  * @summary javadoc should ignore <clinit> methods found in classes on classpath
- * @modules jdk.javadoc
+ * @modules jdk.javadoc/jdk.javadoc.internal.tool
  */
 
 import java.io.*;
@@ -69,7 +69,7 @@
         PrintStream prev = System.err;
         System.setErr(ps);
         try {
-            int rc = com.sun.tools.javadoc.Main.execute(args);
+            int rc = jdk.javadoc.internal.tool.Main.execute(args);
         } finally {
             System.err.flush();
             System.setErr(prev);
--- a/langtools/test/jdk/javadoc/tool/T4696488.java	Wed Aug 10 15:54:25 2016 -0700
+++ b/langtools/test/jdk/javadoc/tool/T4696488.java	Wed Aug 10 16:19:09 2016 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -21,16 +21,17 @@
  * questions.
  */
 
-import com.sun.tools.doclets.internal.toolkit.Configuration;
-
 /**
  * @test
  * @bug     4696488
  * @summary javadoc doesn't handle UNC paths for destination directory
  * @author  Jesse Glick
- * @modules jdk.javadoc/com.sun.tools.doclets.internal.toolkit
+ * @modules jdk.javadoc/jdk.javadoc.internal.doclets.toolkit
  * @run main T4696488 T4696488.java
  */
+
+import jdk.javadoc.internal.doclets.toolkit.Configuration;
+
 public class T4696488 {
 
     public static void main(String... args) {
@@ -53,5 +54,4 @@
             throw new Error("expected " + expectedOutput + " but was " + output);
         }
     }
-
 }
--- a/langtools/test/jdk/javadoc/tool/badSuper/BadSuper.java	Wed Aug 10 15:54:25 2016 -0700
+++ b/langtools/test/jdk/javadoc/tool/badSuper/BadSuper.java	Wed Aug 10 16:19:09 2016 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2004, 2016, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,7 +25,7 @@
  * @test
  * @bug 4983023
  * @summary A bad superclass shouldn't throw the standard doclet into a loop
- * @modules jdk.javadoc
+ * @modules jdk.javadoc/jdk.javadoc.internal.tool
  */
 
 public class BadSuper {
@@ -33,7 +33,7 @@
     public static void main(String[] args) {
         String srcpath = System.getProperty("test.src", ".");
 
-        if (com.sun.tools.javadoc.Main.execute(
+        if (jdk.javadoc.internal.tool.Main.execute(
                 new String[] {"-d", "doc", "-sourcepath", srcpath, "p"}) != 0)
             throw new Error("Javadoc encountered warnings or errors.");
     }
--- a/langtools/test/jdk/javadoc/tool/enum/docComments/Main.java	Wed Aug 10 15:54:25 2016 -0700
+++ b/langtools/test/jdk/javadoc/tool/enum/docComments/Main.java	Wed Aug 10 16:19:09 2016 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2003, 2016, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,7 +25,7 @@
  * @test
  * @bug 4421066
  * @summary Verify the comments in an enum type.
- * @ignore API modifications
+ * @ignore 8152313 convert to doclet test framework
  * @library ../../lib
  * @modules jdk.javadoc
  * @compile  ../../lib/Tester.java Main.java
--- a/langtools/test/jdk/javadoc/tool/enum/enumType/Main.java	Wed Aug 10 15:54:25 2016 -0700
+++ b/langtools/test/jdk/javadoc/tool/enum/enumType/Main.java	Wed Aug 10 16:19:09 2016 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2003, 2016, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,7 +25,7 @@
  * @test
  * @bug 4421066
  * @summary Verify the contents of an enum type.
- * @ignore API modifications
+ * @ignore 8152313 convert to doclet test framework
  * @library ../../lib
  * @modules jdk.javadoc
  * @compile  ../../lib/Tester.java Main.java
--- a/langtools/test/jdk/javadoc/tool/generics/genericClass/Main.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,58 +0,0 @@
-/*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-/*
- * @test
- * @bug 4421066
- * @summary Verify the contents of the ClassDoc of a generic class.
- * @ignore API modifications
- * @library ../../lib
- * @modules jdk.javadoc
- * @compile  ../../lib/Tester.java Main.java
- * @run main Main
- */
-
-import java.io.IOException;
-import com.sun.javadoc.*;
-
-public class Main extends Tester.Doclet {
-
-    private static final Tester tester = new Tester("Main", "pkg1");
-
-    public static void main(String[] args) throws IOException {
-        tester.run();
-        tester.verify();
-    }
-
-    public static boolean run(DocletEnvironment root) {
-        try {
-            for (ClassDoc cd : root.classes()) {
-                tester.printClass(cd);
-            }
-
-            return true;
-        } catch (IOException e) {
-            return false;
-        }
-    }
-}
--- a/langtools/test/jdk/javadoc/tool/generics/genericClass/expected.out	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,16 +0,0 @@
-class pkg1.A<T>
-  name: A / A / pkg1.A
-  type parameters:
-    T
-  superclass:
-    java.lang.Object
-  fields:
-    T t
-    pkg1.A<T> at
-    pkg1.A<java.lang.String> as
-  constructors:
-    A()
-  methods:
-    void m1(T)
-    void m2(A<T>)
-    void m3(A<String>)
--- a/langtools/test/jdk/javadoc/tool/generics/genericClass/pkg1/A.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,34 +0,0 @@
-/*
- * Copyright (c) 2003, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-package pkg1;
-
-public class A<T> {
-    public T t;
-    public A<T> at;
-    public A<String> as;
-
-    public void m1(T t) {}
-    public void m2(A<T> at) {}
-    public void m3(A<String> as) {}
-}
--- a/langtools/test/jdk/javadoc/tool/generics/genericInnerAndOuter/Main.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,63 +0,0 @@
-/*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-/*
- * @test
- * @bug 4421066
- * @summary Verify the contents of the ClassDoc of
- *          a generic class with a generic inner class.
- * @ignore API modifications
- * @library ../../lib
- * @modules jdk.javadoc
- * @compile  ../../lib/Tester.java Main.java
- * @run main Main
- */
-
-import java.io.IOException;
-import java.util.Arrays;
-import com.sun.javadoc.*;
-
-public class Main extends Tester.Doclet {
-
-    private static final Tester tester = new Tester("Main", "pkg1");
-
-    public static void main(String[] args) throws IOException {
-        tester.run();
-        tester.verify();
-    }
-
-    public static boolean run(DocletEnvironment root) {
-        try {
-            ClassDoc[] cds = root.classes();
-            Arrays.sort(cds);
-            for (ClassDoc cd : cds) {
-                tester.printClass(cd);
-                tester.println();
-            }
-
-            return true;
-        } catch (IOException e) {
-            return false;
-        }
-    }
-}
--- a/langtools/test/jdk/javadoc/tool/generics/genericInnerAndOuter/expected.out	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,53 +0,0 @@
-class pkg1.O<T>
-  name: O / O / pkg1.O
-  type parameters:
-    T
-  superclass:
-    java.lang.Object
-  constructors:
-    O()
-
-class pkg1.O<T>.I<S>
-  name: I / O.I / pkg1.O.I
-  type parameters:
-    S
-  nested in:
-    pkg1.O<T>
-  superclass:
-    java.lang.Object
-  constructors:
-    I()
-  methods:
-    void m1(O<String>.I<Number>)
-
-class pkg1.X<T>
-  name: X / X / pkg1.X
-  type parameters:
-    T
-  superclass:
-    java.lang.Object
-  constructors:
-    X()
-
-class pkg1.X<T>.Y
-  name: Y / X.Y / pkg1.X.Y
-  nested in:
-    pkg1.X<T>
-  superclass:
-    java.lang.Object
-  constructors:
-    Y()
-
-class pkg1.X<T>.Y.Z<S>
-  name: Z / X.Y.Z / pkg1.X.Y.Z
-  type parameters:
-    S
-  nested in:
-    pkg1.X<T>.Y
-  superclass:
-    java.lang.Object
-  constructors:
-    Z()
-  methods:
-    void m1(X<String>.Y.Z<Number>)
-
--- a/langtools/test/jdk/javadoc/tool/generics/genericInnerAndOuter/pkg1/O.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,30 +0,0 @@
-/*
- * Copyright (c) 2003, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-package pkg1;
-
-public class O<T> {
-    public class I<S> {
-        public void m1(O<String>.I<Number> a) {}
-    }
-}
--- a/langtools/test/jdk/javadoc/tool/generics/genericInnerAndOuter/pkg1/X.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,32 +0,0 @@
-/*
- * Copyright (c) 2003, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-package pkg1;
-
-public class X<T> {
-    public class Y {
-        public class Z<S> {
-            public void m1(X<String>.Y.Z<Number> a) {}
-        }
-    }
-}
--- a/langtools/test/jdk/javadoc/tool/generics/genericInterface/Main.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,58 +0,0 @@
-/*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-/*
- * @test
- * @bug 4421066
- * @summary Verify the contents of the ClassDoc of a generic interface.
- * @ignore API modifications
- * @library ../../lib
- * @modules jdk.javadoc
- * @compile  ../../lib/Tester.java Main.java
- * @run main Main
- */
-
-import java.io.IOException;
-import com.sun.javadoc.*;
-
-public class Main extends Tester.Doclet {
-
-    private static final Tester tester = new Tester("Main", "pkg1");
-
-    public static void main(String[] args) throws IOException {
-        tester.run();
-        tester.verify();
-    }
-
-    public static boolean run(DocletEnvironment root) {
-        try {
-            for (ClassDoc cd : root.classes()) {
-                tester.printClass(cd);
-            }
-
-            return true;
-        } catch (IOException e) {
-            return false;
-        }
-    }
-}
--- a/langtools/test/jdk/javadoc/tool/generics/genericInterface/expected.out	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,6 +0,0 @@
-interface pkg1.A<T>
-  name: A / A / pkg1.A
-  type parameters:
-    T
-  methods:
-    void m1(T)
--- a/langtools/test/jdk/javadoc/tool/generics/genericInterface/pkg1/A.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,28 +0,0 @@
-/*
- * Copyright (c) 2003, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-package pkg1;
-
-public interface A<T> {
-    void m1(T t);
-}
--- a/langtools/test/jdk/javadoc/tool/generics/genericMethod/Main.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,61 +0,0 @@
-/*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-/*
- * @test
- * @bug 4421066
- * @summary Verify the reading of generic methods and constructors.
- * @ignore API modifications
- * @library ../../lib
- * @modules jdk.javadoc
- * @compile  ../../lib/Tester.java Main.java
- * @run main Main
- */
-
-import java.io.IOException;
-import com.sun.javadoc.*;
-
-public class Main extends Tester.Doclet {
-
-    private static final Tester tester = new Tester("Main", "pkg1");
-
-    public static void main(String[] args) throws IOException {
-        tester.run();
-        tester.verify();
-    }
-
-    public static boolean run(DocletEnvironment root) {
-        try {
-            for (ClassDoc cd : root.classes()) {
-                for (ConstructorDoc c : cd.constructors())
-                    tester.printConstructor(c);
-                for (MethodDoc m : cd.methods())
-                    tester.printMethod(m);
-            }
-
-            return true;
-        } catch (IOException e) {
-            return false;
-        }
-    }
-}
--- a/langtools/test/jdk/javadoc/tool/generics/genericMethod/expected.out	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,20 +0,0 @@
-constructor <T>pkg1.A()
-  signature: ()
-             ()
-  type parameters:
-    T
-method pkg1.A.<T>m1(T)
-  signature: (T)
-             (T)
-  type parameters:
-    T
-  returns:
-    void
-method pkg1.A.<T extends java.lang.Number, U>m2(T, U)
-  signature: (T, U)
-             (T, U)
-  type parameters:
-    T extends java.lang.Number
-    U
-  returns:
-    void
--- a/langtools/test/jdk/javadoc/tool/generics/genericMethod/pkg1/A.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,30 +0,0 @@
-/*
- * Copyright (c) 2003, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-package pkg1;
-
-public class A {
-    public <T> A() {}
-    public <T> void m1(T t) {}
-    public <T extends Number, U> void m2(T t, U u) {}
-}
--- a/langtools/test/jdk/javadoc/tool/generics/genericSuper/Main.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,63 +0,0 @@
-/*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-/*
- * @test
- * @bug 4421066
- * @summary Verify the contents of the ClassDoc of a generic class.
- * @ignore API modifications
- * @library ../../lib
- * @modules jdk.javadoc
- * @compile  ../../lib/Tester.java Main.java
- * @run main Main
- */
-
-import java.io.IOException;
-import java.util.Arrays;
-import com.sun.javadoc.*;
-
-public class Main extends Tester.Doclet {
-
-    private static final Tester tester =
-            new Tester("Main", "pkg1", "-package");
-
-    public static void main(String[] args) throws IOException {
-        tester.run();
-        tester.verify();
-    }
-
-    public static boolean run(DocletEnvironment root) {
-        try {
-            ClassDoc[] cds = root.classes();
-            Arrays.sort(cds);
-            for (ClassDoc cd : cds) {
-                tester.printClass(cd);
-                tester.println();
-            }
-
-            return true;
-        } catch (IOException e) {
-            return false;
-        }
-    }
-}
--- a/langtools/test/jdk/javadoc/tool/generics/genericSuper/expected.out	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,27 +0,0 @@
-class pkg1.A<V, W>
-  name: A / A / pkg1.A
-  type parameters:
-    V
-    W
-  superclass:
-    pkg1.S<W, V>
-  interfaces:
-    pkg1.I<java.lang.String>
-  constructors:
-    A()
-
-interface pkg1.I<R>
-  name: I / I / pkg1.I
-  type parameters:
-    R
-
-class pkg1.S<T, U>
-  name: S / S / pkg1.S
-  type parameters:
-    T
-    U
-  superclass:
-    java.lang.Object
-  constructors:
-    S()
-
--- a/langtools/test/jdk/javadoc/tool/generics/genericSuper/pkg1/A.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,33 +0,0 @@
-/*
- * Copyright (c) 2003, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-package pkg1;
-
-class S<T,U> {
-}
-
-interface I<R> {
-}
-
-public class A<V,W> extends S<W,V> implements I<String> {
-}
--- a/langtools/test/jdk/javadoc/tool/generics/supertypes/Main.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,81 +0,0 @@
-/*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-/*
- * @test
- * @bug 4922918
- * @summary Check supertypes and superinterfaces of parameterized types.
- * @ignore API modifications
- * @library ../../lib
- * @modules jdk.javadoc
- * @compile  ../../lib/Tester.java Main.java
- * @run main Main
- */
-
-import java.io.IOException;
-import java.util.Comparator;
-import java.util.Arrays;
-import com.sun.javadoc.*;
-
-public class Main extends Tester.Doclet {
-
-    private static final Tester tester = new Tester("Main", "pkg1");
-
-    public static void main(String[] args) throws IOException {
-        tester.run();
-        tester.verify();
-    }
-
-    public static boolean run(DocletEnvironment root) {
-        try {
-            ClassDoc[] cds = root.classes();
-            Arrays.sort(cds);
-            for (ClassDoc cd : cds) {
-                ParameterizedType arrayList =
-                    cd.superclassType().asParameterizedType();
-                tester.println(arrayList);
-                tester.println();
-
-                tester.println(arrayList.superclassType());
-                Type[] interfaces = arrayList.interfaceTypes();
-                // Sort interfaces by type name, for consistent output.
-                Arrays.sort(interfaces,
-                            new Comparator<Type>() {
-                                    public int compare(Type t1, Type t2) {
-                                        String name1 = t1.qualifiedTypeName();
-                                        String name2 = t2.qualifiedTypeName();
-                                        return name1.compareTo(name2);
-                                    }
-                                });
-                for (Type t : interfaces) {
-                    tester.println(t);
-                }
-                tester.println();
-            }
-
-            return true;
-        } catch (IOException e) {
-            return false;
-        }
-    }
-}
--- a/langtools/test/jdk/javadoc/tool/generics/supertypes/expected.out	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,16 +0,0 @@
-java.util.ArrayList<java.lang.String>
-
-java.util.AbstractList<java.lang.String>
-java.io.Serializable
-java.lang.Cloneable
-java.util.List<java.lang.String>
-java.util.RandomAccess
-
-java.util.ArrayList<X>
-
-java.util.AbstractList<X>
-java.io.Serializable
-java.lang.Cloneable
-java.util.List<X>
-java.util.RandomAccess
-
--- a/langtools/test/jdk/javadoc/tool/generics/supertypes/pkg1/A.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,29 +0,0 @@
-/*
- * Copyright (c) 2003, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-package pkg1;
-
-import java.util.ArrayList;
-
-public class A extends ArrayList<String> {
-}
--- a/langtools/test/jdk/javadoc/tool/generics/supertypes/pkg1/B.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,29 +0,0 @@
-/*
- * Copyright (c) 2003, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-package pkg1;
-
-import java.util.ArrayList;
-
-public class B<X> extends ArrayList<X> {
-}
--- a/langtools/test/jdk/javadoc/tool/generics/throwsGeneric/Main.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,59 +0,0 @@
-/*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-/*
- * @test
- * @bug 4421066
- * @summary Verify the reading of generic methods and constructors.
- * @ignore API modifications
- * @library ../../lib
- * @modules jdk.javadoc
- * @compile  ../../lib/Tester.java Main.java
- * @run main Main
- */
-
-import java.io.IOException;
-import com.sun.javadoc.*;
-
-public class Main extends Tester.Doclet {
-
-    private static final Tester tester = new Tester("Main", "pkg1");
-
-    public static void main(String[] args) throws IOException {
-        tester.run();
-        tester.verify();
-    }
-
-    public static boolean run(DocletEnvironment root) {
-        try {
-            for (ClassDoc cd : root.classes()) {
-                for (MethodDoc m : cd.methods())
-                    tester.printMethod(m);
-            }
-
-            return true;
-        } catch (IOException e) {
-            return false;
-        }
-    }
-}
--- a/langtools/test/jdk/javadoc/tool/generics/throwsGeneric/expected.out	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,16 +0,0 @@
-method pkg1.A.m1()
-  signature: ()
-             ()
-  throws:
-    T extends java.lang.Throwable
-  returns:
-    void
-method pkg1.A.<U extends java.lang.Throwable>m2()
-  signature: ()
-             ()
-  type parameters:
-    U extends java.lang.Throwable
-  throws:
-    U extends java.lang.Throwable
-  returns:
-    void
--- a/langtools/test/jdk/javadoc/tool/generics/throwsGeneric/pkg1/A.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,29 +0,0 @@
-/*
- * Copyright (c) 2003, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-package pkg1;
-
-public interface A<T extends Throwable> {
-    void m1() throws T;
-    <U extends Throwable> void m2() throws U;
-}
--- a/langtools/test/jdk/javadoc/tool/generics/tparamCycle/Main.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,64 +0,0 @@
-/*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-/*
- * @test
- * @bug 4421066
- * @summary Check a type parameter whose bound cycles back on itself.
- * @ignore API modifications
- * @library ../../lib
- * @modules jdk.javadoc
- * @compile  ../../lib/Tester.java Main.java
- * @run main Main
- */
-
-import java.io.IOException;
-import com.sun.javadoc.*;
-
-public class Main extends Tester.Doclet {
-
-    private static final Tester tester = new Tester("Main", "pkg1");
-
-    public static void main(String[] args) throws IOException {
-        tester.run();
-    }
-
-    public static boolean run(DocletEnvironment root) {
-        ClassDoc cd = root.classes()[0];
-        System.out.println("*** " + cd);
-        TypeVariable E = cd.typeParameters()[0];
-        System.out.println("*** " + E);
-        Type bound = E.bounds()[0];
-        System.out.println("*** " + bound);
-
-        // Verify that we have an instantiation of Enum<E>, and not
-        // the generic interface.
-        ParameterizedType enumE = (ParameterizedType)bound;
-
-        if (enumE.asClassDoc() != cd) {
-            throw new Error("Type declaration and type use don't match up.");
-        } else {
-            return true;
-        }
-    }
-}
--- a/langtools/test/jdk/javadoc/tool/generics/tparamCycle/pkg1/LikeEnum.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,27 +0,0 @@
-/*
- * Copyright (c) 2003, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-package pkg1;
-
-public interface LikeEnum<E extends LikeEnum<E>> {
-}
--- a/langtools/test/jdk/javadoc/tool/generics/tparamTagOnMethod/Main.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,60 +0,0 @@
-/*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-/*
- * @test
- * @bug 4421066
- * @summary Verify the reading of type parameter tags on methods.
- * @ignore API modifications
- * @library ../../lib
- * @modules jdk.javadoc
- * @compile  ../../lib/Tester.java Main.java
- * @run main Main
- */
-
-import java.io.IOException;
-import com.sun.javadoc.*;
-
-public class Main extends Tester.Doclet {
-
-    private static final Tester tester = new Tester("Main", "pkg1");
-
-    public static void main(String[] args) throws IOException {
-        tester.run();
-        tester.verify();
-    }
-
-    public static boolean run(DocletEnvironment root) {
-        try {
-            for (ClassDoc cd : root.classes()) {
-                for (MethodDoc m : cd.methods()) {
-                    tester.printMethod(m);
-                }
-            }
-
-            return true;
-        } catch (IOException e) {
-            return false;
-        }
-    }
-}
--- a/langtools/test/jdk/javadoc/tool/generics/tparamTagOnMethod/expected.out	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,12 +0,0 @@
-method pkg1.A.<T, U>m1(T, U)
-  signature: (T, U)
-             (T, U)
-  @param <T> the kind of thing
-  @param <U> the other kind of thing
-  @param t the thing itself
-  @param u the other thing
-  type parameters:
-    T
-    U
-  returns:
-    void
--- a/langtools/test/jdk/javadoc/tool/generics/tparamTagOnMethod/pkg1/A.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,34 +0,0 @@
-/*
- * Copyright (c) 2003, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-package pkg1;
-
-public interface A {
-    /**
-     * @param <T> the kind of thing
-     * @param <U> the other kind of thing
-     * @param t the thing itself
-     * @param u the other thing
-     */
-    public <T,U> void m1(T t, U u);
-}
--- a/langtools/test/jdk/javadoc/tool/generics/tparamTagOnType/Main.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,58 +0,0 @@
-/*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-/*
- * @test
- * @bug 4421066
- * @summary Verify the reading of a type parameter tag on an interface.
- * @ignore API modifications
- * @library ../../lib
- * @modules jdk.javadoc
- * @compile  ../../lib/Tester.java Main.java
- * @run main Main
- */
-
-import java.io.IOException;
-import com.sun.javadoc.*;
-
-public class Main extends Tester.Doclet {
-
-    private static final Tester tester = new Tester("Main", "pkg1");
-
-    public static void main(String[] args) throws IOException {
-        tester.run();
-        tester.verify();
-    }
-
-    public static boolean run(DocletEnvironment root) {
-        try {
-            for (ClassDoc cd : root.classes()) {
-                tester.printClass(cd);
-            }
-
-            return true;
-        } catch (IOException e) {
-            return false;
-        }
-    }
-}
--- a/langtools/test/jdk/javadoc/tool/generics/tparamTagOnType/expected.out	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,5 +0,0 @@
-interface pkg1.A<T>
-  name: A / A / pkg1.A
-  type parameters:
-    T
-  @param <T> the type parameter
--- a/langtools/test/jdk/javadoc/tool/generics/tparamTagOnType/pkg1/A.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,30 +0,0 @@
-/*
- * Copyright (c) 2003, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-package pkg1;
-
-/**
- * @param <T> the type parameter
- */
-public interface A<T> {
-}
--- a/langtools/test/jdk/javadoc/tool/generics/wildcards/Main.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,58 +0,0 @@
-/*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-/*
- * @test
- * @bug 4421066
- * @summary Verify the contents of the ClassDoc of a generic class.
- * @ignore API modifications
- * @library ../../lib
- * @modules jdk.javadoc
- * @compile  ../../lib/Tester.java Main.java
- * @run main Main
- */
-
-import java.io.IOException;
-import com.sun.javadoc.*;
-
-public class Main extends Tester.Doclet {
-
-    private static final Tester tester = new Tester("Main", "pkg1");
-
-    public static void main(String[] args) throws IOException {
-        tester.run();
-        tester.verify();
-    }
-
-    public static boolean run(DocletEnvironment root) {
-        try {
-            for (ClassDoc cd : root.classes()) {
-                tester.printClass(cd);
-            }
-
-            return true;
-        } catch (IOException e) {
-            return false;
-        }
-    }
-}
--- a/langtools/test/jdk/javadoc/tool/generics/wildcards/expected.out	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,16 +0,0 @@
-class pkg1.A<T>
-  name: A / A / pkg1.A
-  type parameters:
-    T
-  superclass:
-    java.lang.Object
-  fields:
-    pkg1.A<?> f1
-    pkg1.A<? extends java.lang.Number> f2
-    pkg1.A<? super java.lang.Long> f3
-  constructors:
-    A()
-  methods:
-    void m1(A<?>)
-    void m2(A<? extends Number>)
-    void m3(A<? super Long>)
--- a/langtools/test/jdk/javadoc/tool/generics/wildcards/pkg1/A.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,34 +0,0 @@
-/*
- * Copyright (c) 2003, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-package pkg1;
-
-public class A<T> {
-    public A<?> f1;
-    public A<? extends Number> f2;
-    public A<? super Long> f3;
-
-    public void m1(A<?> p1) {}
-    public void m2(A<? extends Number> p2) {}
-    public void m3(A<? super Long> p3) {}
-}
--- a/langtools/test/jdk/javadoc/tool/imports/I.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,29 +0,0 @@
-/*
- * Copyright (c) 2004, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-// The following imported class is bogus, but should still be returned
-// when inquired of.
-import bo.o.o.o.Gus;
-
-public interface I {
-}
--- a/langtools/test/jdk/javadoc/tool/imports/MissingImport.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,83 +0,0 @@
-/*
- * Copyright (c) 2004, 2015, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-/*
- * @test
- * @bug 5012972
- * @summary ClassDoc.getImportedClasses should return a class even if
- *          it's not in the classpath.
- * @ignore API modifications, testing deprecated APIs.
- * @modules jdk.javadoc
- */
-
-import java.util.Collections;
-import java.util.Set;
-import javax.lang.model.SourceVersion;
-import jdk.javadoc.doclet.Doclet;
-import jdk.javadoc.doclet.Doclet.Option;
-import jdk.javadoc.doclet.DocletEnvironment;
-
-
-public class MissingImport implements Doclet {
-
-    public static void main(String[] args) {
-        String thisFile = "" +
-            new java.io.File(System.getProperty("test.src", "."),
-                             "I.java");
-        String[] toolargs = {
-            "-doclet", "MissingImport",
-            "-docletpath", System.getProperty("test.classes", "."),
-            thisFile
-        };
-        if (com.sun.tools.javadoc.Main.execute(toolargs) != 0)
-            throw new Error("Javadoc encountered warnings or errors.");
-    }
-
-    /*
-     * The world's simplest doclet.
-     */
-    public static boolean run(DocletEnvironment root) {
-        ClassDoc c = root.classNamed("I");
-        ClassDoc[] imps = c.importedClasses();
-        if (imps.length == 0 ||
-            !imps[0].qualifiedName().equals("bo.o.o.o.Gus")) {
-            throw new Error("Import bo.o.o.o.Gus not found");
-        }
-        return true;
-    }
-
-    @Override
-    public String getName() {
-        return "Test";
-    }
-
-    @Override
-    public Set<Option> getSupportedOptions() {
-        return Collections.emptySet();
-    }
-
-    @Override
-    public SourceVersion getSupportedSourceVersion() {
-        return SourceVersion.latest();
-    }
-}
--- a/langtools/test/jdk/javadoc/tool/lib/Tester.java	Wed Aug 10 15:54:25 2016 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,331 +0,0 @@
-/*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-/*
- * A utility used to invoke and test the javadoc tool.
- *
- * @author Scott Seligman
- */
-
-
-import java.io.*;
-import java.util.*;
-
-import javax.lang.model.SourceVersion;
-
-
-public class Tester {
-
-    protected final String TEST_SRC = System.getProperty("test.src", ".");
-    protected final String TEST_CLASSES = System.getProperty("test.classes",
-                                                             ".");
-    private final String DEFAULT_ARGS[] = {
-        "-sourcepath", TEST_SRC,
-    };
-
-    private final File outputFile = new File(TEST_CLASSES, "testrun.out");
-    private final File expectedOutputFile = new File(TEST_SRC, "expected.out");
-
-    private String docletName;
-    private String[] args;
-    private Writer out = null;
-
-
-    /*
-     * Individual tests can extend this to create generics-aware doclets.
-     */
-    public abstract class Doclet extends jdk.javadoc.doclet.Doclet {
-
-        @Override
-        public SourceVersion getSupportedSourceVersion() {
-            return super.getSourceVersion();
-        }
-
-    }
-
-
-    public Tester(String docletName) {
-        this(docletName, new String[0]);
-    }
-
-    public Tester(String docletName, String... additionalArgs) {
-        this.docletName = docletName;
-        List<String> args = new ArrayList<>();
-        args.addAll(Arrays.asList(DEFAULT_ARGS));
-        args.addAll(Arrays.asList(additionalArgs));
-
-        try {
-            out = new BufferedWriter(new FileWriter(outputFile));
-        } catch (IOException e) {
-            throw new Error("Could not open output file " + outputFile);
-        }
-    }
-
-    public void run() throws IOException {
-        try {
-            if (Main.execute("javadoc", docletName, getClass().getClassLoader(), args) != 0) {
-                throw new Error("Javadoc errors encountered.");
-            }
-            System.out.println("--> Output written to " + outputFile);
-        } finally {
-            out.close();
-        }
-    }
-
-    /*
-     * Compare output of test run to expected output.
-     * Throw an Error if they don't match.
-     */
-    public void verify() throws IOException {
-        BufferedReader thisRun =
-            new BufferedReader(new FileReader(outputFile));
-        BufferedReader expected =
-            new BufferedReader(new FileReader(expectedOutputFile));
-
-        for (int lineNum = 1; true; lineNum++) {
-            String line1 = thisRun.readLine();
-            String line2 = expected.readLine();
-            if (line1 == null && line2 == null) {
-                return;         // EOF with all lines matching
-            }
-            if (line1 == null || !line1.equals(line2)) {
-                throw new Error(outputFile + ":" + lineNum +
-                                ": output doesn't match");
-            }
-        }
-    }
-
-
-    public void println(Object o) throws IOException {
-        prln(0, o);
-    }
-
-    public void println() throws IOException {
-        prln();
-    }
-//
-//    public void printPackage(PackageDoc p) throws IOException {
-//        prPackage(0, p);
-//    }
-//
-//    public void printClass(ClassDoc cd) throws IOException {
-//        if (cd.isAnnotationType())
-//            printAnnotationType((AnnotationTypeDoc)cd);
-//        else
-//            prClass(0, cd);
-//    }
-//
-//    public void printAnnotationType(AnnotationTypeDoc at) throws IOException {
-//        prAnnotationType(0, at);
-//    }
-//
-//    public void printField(FieldDoc f) throws IOException {
-//        prField(0, f);
-//    }
-//
-//    public void printParameter(Parameter p) throws IOException {
-//        prParameter(0, p);
-//    }
-//
-//    public void printMethod(MethodDoc m) throws IOException {
-//        prln(0, "method " + m);
-//        prMethod(0, m);
-//    }
-//
-//    public void printAnnotationTypeElement(AnnotationTypeElementDoc e)
-//                                                        throws IOException {
-//        prln(0, "element " + e);
-//        prMethod(0, e);
-//    }
-//
-//    public void printConstructor(ConstructorDoc c) throws IOException {
-//        prln(0, "constructor " + c);
-//        prExecutable(0, c);
-//    }
-//
-//
-//    private void prPackage(int off, PackageDoc p) throws IOException {
-//        prln(off, "package " + p);
-//        prAnnotations(off + 2, p.annotations());
-//    }
-//
-//    private void prClass(int off, ClassDoc cd) throws IOException {
-//        prln(off,
-//             (cd.isInterface() ? "interface" : cd.isEnum() ? "enum" : "class")
-//             + " " + cd);
-//        prln(off + 2, "name: " + cd.simpleTypeName() + " / " +
-//             cd.typeName() + " / " + cd.qualifiedTypeName());
-//        prAnnotations(off + 2, cd.annotations());
-//        prLabel(off + 2, "type parameters");
-//        for (Type t : cd.typeParameters())
-//            prln(off + 4, t);
-//        prParamTags(off + 2, cd.typeParamTags());
-//        prLabel(off + 2, "nested in");
-//        prln(off + 4, cd.containingClass());
-//        prLabel(off + 2, "superclass");
-//        prln(off + 4, cd.superclassType());
-//        prLabel(off + 2, "interfaces");
-//        Type[] ts = cd.interfaceTypes();
-//        Arrays.sort(ts);
-//        for (Type t : ts)
-//            prln(off + 4, t);
-//        prLabel(off + 2, "enum constants");
-//        for (FieldDoc f : cd.enumConstants())
-//            prln(off + 4, f.name());
-//        prLabel(off + 2, "fields");
-//        for (FieldDoc f : cd.fields())
-//            prln(off + 4, f.type() + " " + f.name());
-//        prLabel(off + 2, "constructors");
-//        for (ConstructorDoc c : cd.constructors())
-//            prln(off + 4, c.name() + c.flatSignature());
-//        prLabel(off + 2, "methods");
-//        for (MethodDoc m : cd.methods())
-//            prln(off + 4, typeUseString(m.returnType()) + " " +
-//                          m.name() + m.flatSignature());
-//    }
-//
-//    private void prAnnotationType(int off, AnnotationTypeDoc at)
-//                                                        throws IOException {
-//        prln(off, "@interface " + at);
-//        prAnnotations(off + 2, at.annotations());
-//        prLabel(off + 2, "elements");
-//        for (AnnotationTypeElementDoc e : at.elements()) {
-//            String def = (e.defaultValue() == null)
-//                                ? ""
-//                                : " default " + e.defaultValue();
-//            prln(off + 4, typeUseString(e.returnType()) + " " + e.name() +
-//                          e.flatSignature() + def);
-//        }
-//    }
-//
-//    private void prField(int off, FieldDoc f) throws IOException {
-//        prln(off, "field " + typeUseString(f.type()) + " " + f.name());
-//        prAnnotations(off + 2, f.annotations());
-//    }
-//
-//    private void prParameter(int off, Parameter p) throws IOException {
-//        prln(off, "parameter " + p);
-//        prAnnotations(off + 2, p.annotations());
-//    }
-//
-//    private void prMethod(int off, MethodDoc m) throws IOException {
-//        prExecutable(off, m);
-//        prLabel(off + 2, "returns");
-//        prln(off + 4, typeUseString(m.returnType()));
-//        prLabel(off + 2, "overridden type");
-//        prln(off + 4, m.overriddenType());
-//    }
-//
-//    private void prExecutable(int off, ExecutableMemberDoc m)
-//                                                        throws IOException {
-//        if (!m.isAnnotationTypeElement()) {
-//            prln(off + 2, "signature: " + m.flatSignature());
-//            prln(off + 2, "           " + m.signature());
-//        }
-//        prAnnotations(off + 2, m.annotations());
-//        prParamTags(off + 2, m.typeParamTags());
-//        prParamTags(off + 2, m.paramTags());
-//        prLabel(off + 2, "type parameters");
-//        for (Type t : m.typeParameters())
-//            prln(off + 4, t);
-//        prLabel(off + 2, "throws");
-//        Type[] ts = m.thrownExceptionTypes();
-//        Arrays.sort(ts);
-//        for (Type t : ts)
-//            prln(off + 4, t);
-//    }
-//
-//    private void prAnnotations(int off, AnnotationDesc[] as)
-//                                                        throws IOException {
-//        prLabel(off, "annotations");
-//        for (AnnotationDesc a : as)
-//            prln(off + 2, a.toString());
-//    }
-//
-//    private void prParamTags(int off, ParamTag tags[]) throws IOException {
-//        for (ParamTag tag : tags)
-//            prParamTag(off, tag);
-//    }
-//
-//    private void prParamTag(int off, ParamTag tag) throws IOException {
-//        String name = tag.parameterName();
-//        if (tag.isTypeParameter()) name = "<" + name + ">";
-//        prln(off, "@param " + name + " " + tag.parameterComment());
-//    }
-//
-//
-//    private String typeUseString(Type t) {
-//        return (t instanceof ClassDoc || t instanceof TypeVariable)
-//                ? t.typeName()
-//                : t.toString();
-//    }
-
-
-    // Labels queued for possible printing.  Innermost is first in list.
-    List<Line> labels = new ArrayList<Line>();
-
-    // Print label if its section is nonempty.
-    void prLabel(int off, String s) {
-        while (!labels.isEmpty() && labels.get(0).off >= off)
-            labels.remove(0);
-        labels.add(0, new Line(off, s));
-    }
-
-    // Print queued labels with offsets less than "off".
-    void popLabels(int off) throws IOException {
-        while (!labels.isEmpty()) {
-            Line label = labels.remove(0);
-            if (label.off < off)
-                prln(label.off, label.o + ":");
-        }
-    }
-
-    // Print "o" at given offset.
-    void pr(int off, Object o) throws IOException {
-        popLabels(off);
-        for (int i = 0; i < off; i++)
-            out.write(' ');
-        if (o != null)
-            out.write(o.toString());
-    }
-
-    // Print "o" (if non-null) at given offset, then newline.
-    void prln(int off, Object o) throws IOException {
-        if (o != null) {
-            pr(off, o);
-            prln();
-        }
-    }
-
-    // Print newline.
-    void prln() throws IOException {
-        out.write('\n');        // don't want platform-dependent separator
-    }
-
-
-    static class Line {
-        int off;
-        Object o;
-        Line(int off, Object o) { this.off = off; this.o = o; }
-    }
-}
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/langtools/test/jdk/javadoc/tool/sourceOnly/p/NonSource.jasm	Wed Aug 10 16:19:09 2016 -0700
@@ -0,0 +1,36 @@
+/*
+ * Copyright (c) 2016, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ *
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.
+ *
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
+ *
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
+ */
+
+package  p;
+
+super public class NonSource
+        version 46:0
+{
+    public Method "<init>":"()V"
+        stack 1 locals 1
+    {
+                aload_0;
+                invokespecial   Method java/lang/Object."<init>":"()V";
+                return;
+    }
+}
--- a/langtools/test/jdk/javadoc/tool/sourceOnly/p/SourceOnly.java	Wed Aug 10 15:54:25 2016 -0700
+++ b/langtools/test/jdk/javadoc/tool/sourceOnly/p/SourceOnly.java	Wed Aug 10 16:19:09 2016 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2002, 2016, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -23,29 +23,27 @@
 
 package p;
 
+import java.util.Arrays;
 import java.util.Collections;
+import java.util.Locale;
 import java.util.Set;
 
 import javax.lang.model.SourceVersion;
 
 import jdk.javadoc.doclet.Doclet;
 import jdk.javadoc.doclet.DocletEnvironment;
+import jdk.javadoc.doclet.Reporter;
 
 /** Test that when running javadoc on a package, we only get
  *  documentation for those classes for which source was provided.
  */
 public class SourceOnly implements Doclet {
-    public static void main(String[] args) {
-        // run javadoc on package p
-        int result = jdk.javadoc.internal.tool.Main.
-            execute("javadoc", "p.SourceOnly", SourceOnly.class.getClassLoader(), new String[] {"p"});
-        if (result != 0)
-            throw new Error();
-    }
-
-    public boolean start(DocletEnvironment root) {
+    NonSource dependency; // force a compilation error if not on classpath.
+    @Override
+    public boolean run(DocletEnvironment root) {
         if (root.getIncludedClasses().size() != 1)
-            throw new Error("wrong set of classes documented: " + java.util.Arrays.asList(root.getIncludedClasses()));
+            throw new Error("wrong set of classes documented: " +
+                    Arrays.asList(root.getIncludedClasses()));
         return true;
     }
 
@@ -63,4 +61,9 @@
     public SourceVersion getSupportedSourceVersion() {
         return SourceVersion.latest();
     }
+
+    @Override
+    public void init(Locale locale, Reporter reporter) {
+        // do nothing
+    }
 }
--- a/langtools/test/jdk/javadoc/tool/sourceOption/SourceOption.java	Wed Aug 10 15:54:25 2016 -0700
+++ b/langtools/test/jdk/javadoc/tool/sourceOption/SourceOption.java	Wed Aug 10 16:19:09 2016 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2006, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2006, 2016, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,8 +26,7 @@
  * @bug     6507179
  * @summary Ensure that "-source" option isn't ignored.
  * @author  Scott Seligman
- * @ignore API modifications
- * @modules jdk.javadoc
+ * @modules jdk.javadoc/jdk.javadoc.internal.tool
  * @run main/fail SourceOption 7
  * @run main      SourceOption 9
  * @run main      SourceOption
@@ -55,34 +54,41 @@
  *      JDK8, JDK9, or JDK10.  Set -source below appropriately.
  */
 
+import java.util.ArrayList;
 import java.util.Collections;
+import java.util.List;
+import java.util.Locale;
 import java.util.Set;
 
 import javax.lang.model.SourceVersion;
+import javax.tools.Diagnostic.Kind;
 
 import jdk.javadoc.doclet.Doclet;
 import jdk.javadoc.doclet.Doclet.Option;
 import jdk.javadoc.doclet.DocletEnvironment;
+import jdk.javadoc.doclet.Reporter;
 
 public class SourceOption implements Doclet {
 
     public static void main(String[] args) {
-        String[] params;
+        List<String> params = new ArrayList<>();
+        params.add("-sourcepath");
+        params.add(System.getProperty("test.src"));
+        params.add("-docletpath");
+        params.add(System.getProperty("test.classes"));
+        params.add("-doclet");
+        params.add("SourceOption");
         if ((args == null) || (args.length==0)) {
-            params = new String[]{"p"};
             System.out.println("NOTE : -source not provided, default taken");
         } else {
-            params = new String[]{"-source", args[0], "p"};
+            params.add("-source");
+            params.add(args[0]);
             System.out.println("NOTE : -source will be: " + args[0]);
         }
-
-        if (com.sun.tools.javadoc.Main.execute(
-                "javadoc",
-                "SourceOption",
-                SourceOption.class.getClassLoader(),
-                params) != 0)
-        throw new Error("Javadoc encountered warnings or errors.");
-
+        params.add("p");
+        System.out.println("arguments: " + params);
+        if (jdk.javadoc.internal.tool.Main.execute(params.toArray(new String[params.size()])) != 0)
+            throw new Error("Javadoc encountered warnings or errors.");
     }
 
     public boolean run(DocletEnvironment root) {
@@ -104,4 +110,9 @@
     public SourceVersion getSupportedSourceVersion() {
         return SourceVersion.latest();
     }
+
+    @Override
+    public void init(Locale locale, Reporter reporter) {
+        reporter.print(Kind.NOTE, "init");
+    }
 }
--- a/langtools/test/jdk/javadoc/tool/subpackageIgnore/SubpackageIgnore.java	Wed Aug 10 15:54:25 2016 -0700
+++ b/langtools/test/jdk/javadoc/tool/subpackageIgnore/SubpackageIgnore.java	Wed Aug 10 16:19:09 2016 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2003, 2016, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,30 +26,33 @@
  * @bug 4773013
  * @summary When hunting subpackages, silently ignore any directory name that
  *          can't be part of a subpackage.
- * @ignore API modifications
- * @modules jdk.javadoc
+ * @modules jdk.javadoc/jdk.javadoc.internal.tool
  */
 
 import java.util.Collections;
+import java.util.Locale;
 import java.util.Set;
 
 import javax.lang.model.SourceVersion;
 
 import jdk.javadoc.doclet.Doclet;
 import jdk.javadoc.doclet.DocletEnvironment;
+import jdk.javadoc.doclet.Reporter;
 
 public class SubpackageIgnore implements Doclet {
 
     public static void main(String[] args) {
-        if (jdk.javadoc.internal.tool.Main.execute(
-                "javadoc",
-                "SubpackageIgnore",
-                SubpackageIgnore.class.getClassLoader(),
-                new String[] {"-Xwerror",
-                              "-sourcepath",
-                              System.getProperty("test.src", "."),
-                              "-subpackages",
-                              "pkg1"}) != 0)
+        String[] cmds = new String[] {
+            "-docletpath",
+            System.getProperty("test.classes"),
+            "-doclet",
+            "SubpackageIgnore",
+            "-Xwerror",
+            "-sourcepath",
+            System.getProperty("test.src", "."),
+            "-subpackages",
+            "pkg1"};
+        if (jdk.javadoc.internal.tool.Main.execute(cmds) != 0)
             throw new Error("Javadoc encountered warnings or errors.");
     }
 
@@ -74,4 +77,9 @@
     public SourceVersion getSupportedSourceVersion() {
         return SourceVersion.latest();
     }
+
+    @Override
+    public void init(Locale locale, Reporter reporter) {
+        // do nothing
+    }
 }
--- a/langtools/test/jdk/javadoc/tool/varArgs/Main.java	Wed Aug 10 15:54:25 2016 -0700
+++ b/langtools/test/jdk/javadoc/tool/varArgs/Main.java	Wed Aug 10 16:19:09 2016 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2003, 2016, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
  * @bug 4421066 5006659
  * @summary Verify the contents of a ClassDoc containing a varArgs method.
  *          Verify that see/link tags can use "..." notation.
- * @ignore API modifications
+ * @ignore 8152313 convert to doclet test framework
  * @library ../lib
  * @modules jdk.javadoc
  * @compile  ../lib/Tester.java Main.java
--- a/langtools/test/jdk/javadoc/tool/sourceOnly/Test.java	Wed Aug 10 15:54:25 2016 -0700
+++ b/langtools/test/jdk/javadoc/tool/sourceOnly/Test.java	Wed Aug 10 16:19:09 2016 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2002, 2016, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,15 +26,15 @@
  * @bug 4548768
  * @summary Javadoc in JDK 1.4 uses classpath and not just source dir
  * @author gafter
  * @ignore API modifications
  * @modules jdk.javadoc
  * @compile p/SourceOnly.java
  * @run main p.SourceOnly
  */
 
-// this file is just a dummy to get the javadoc started.
-//
-// NOTE: this test only seems to work in separate JVM mode for
-// reasons having something to do with javing tools.jar
-// on the classpath.  Until that is sorted out, these tests
-// must be run in separate VM mode.
+public class Test {
+    public static void main(String[] args) {
+        // run javadoc on package p
+        if (jdk.javadoc.internal.tool.Main.execute("javadoc", "p.SourceOnly", "p") != 0)
+            throw new Error();
+    }
+}
@@ -26,15 +26,15 @@
  * @summary Javadoc in JDK 1.4 uses classpath and not just source dir
  * @author gafter
- * @ignore API modifications
- * @modules jdk.javadoc
- * @compile p/SourceOnly.java
- * @run main p.SourceOnly
+ * @modules jdk.javadoc/jdk.javadoc.internal.tool
+ * @compile p/SourceOnly.java p/NonSource.jasm
+ * @run main Test
  */
 